.. _driver/downsample:

``downsample`` Driver
=====================

Virtual read-only view that performs downsampling.

Downsampling is performed on-the-fly to compute exactly the positions of the
downsampled view that are read.

.. json:schema:: driver/downsample

The following downsampling methods are supported:

.. json:schema:: DownsampleMethod
